@@ -30,7 +30,7 @@ EAPI const Eo_Class *elm_ctxpopup_item_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Ctxpopup_Item
  */
-EOAPI Elm_Object_Item * elm_obj_ctxpopup_item_prev_get(void);
+EOAPI Elm_Widget_Item * elm_obj_ctxpopup_item_prev_get(void);
 
 /**
  * @brief Get the item after $ it in a ctxpopup widget's internal list of
@@ -45,14 +45,8 @@ EOAPI Elm_Object_Item * elm_obj_ctxpopup_item_prev_get(void);
  *
  * @ingroup Elm_Ctxpopup_Item
  */
-EOAPI Elm_Object_Item * elm_obj_ctxpopup_item_next_get(void);
+EOAPI Elm_Widget_Item * elm_obj_ctxpopup_item_next_get(void);
 
-/**
- * No description supplied.
- *
- * @param[in] func No description supplied.
- * @param[in] data No description supplied.
- */
 EOAPI void  elm_obj_ctxpopup_item_init(Evas_Smart_Cb func, const void *data);
 
 
